==> xlc_1.0.1.orig.tar.gz: xlc-1.0.1/src/callbacks.h <==
#include <gtk/gtk.h>


void
on_mn_file_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_wnd_acitivity_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_acitivity_unrealize             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_file_configuration_activate      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_server_connect_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_server_shutdown_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_online_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_isdnchannels_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_autohangup_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_reset_mmtput_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cl_lines_select_row                 (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_wnd_linemaster_destroy              (GtkObject       *object,
                                        gpointer         user_data);

void
on_wnd_config_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_linemaster_size_allocate        (GtkWidget       *widget,
                                        GtkAllocation   *allocation,
                                        gpointer         user_data);

void
mn_file_exit_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_wnd_linemaster_realize              (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_linemaster_unrealize            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_line_wnd_activity_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_wnd_activity_toggled        (GtkCheckMenuItem *checkmenuitem,
                                        gpointer         user_data);

void
on_spinbutton1_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_wnd_config_unrealize                (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_messages_realize                (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_messages_unrealize              (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_server_show_message_window_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_bt_close_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_clear_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_conserver_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_conserver_unrealize             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_wnd_conserver_close_clicked      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_bt_config_cancel_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_config_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_autohup_realize                 (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_autohup_unrealize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_ahup_done_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_chk_ahup_time_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_up_toggled                 (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_down_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_total_up_toggled           (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_total_down_toggled         (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_ent_passwd_passwd_key_press_event   (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_bt_passwd_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_passwd_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_passwd_unrealize                (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_wnd_conserver_key_press_event       (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_mn_server_disconnect_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_offline_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chk_ahup_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_activated_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_ed_ahup_lines_changed               (GtkEditable     *editable,
                                        gpointer         user_data);

==> xlc_1.0.6.orig.tar.gz: xlc-1.0.6/src/callbacks.h <==
#include <gtk/gtk.h>


void
on_mn_file_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_wnd_acitivity_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_acitivity_unrealize             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_file_configuration_activate      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_server_connect_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_server_shutdown_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_online_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_isdnchannels_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_autohangup_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_reset_mmtput_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cl_lines_select_row                 (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_wnd_linemaster_destroy              (GtkObject       *object,
                                        gpointer         user_data);

void
on_wnd_config_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_linemaster_size_allocate        (GtkWidget       *widget,
                                        GtkAllocation   *allocation,
                                        gpointer         user_data);

void
mn_file_exit_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_wnd_linemaster_realize              (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_linemaster_unrealize            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_line_wnd_activity_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_wnd_activity_toggled        (GtkCheckMenuItem *checkmenuitem,
                                        gpointer         user_data);

void
on_spinbutton1_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_wnd_config_unrealize                (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_messages_realize                (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_messages_unrealize              (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_server_show_message_window_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_bt_close_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_clear_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_conserver_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_conserver_unrealize             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_wnd_conserver_close_clicked      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_bt_config_cancel_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_config_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_autohup_realize                 (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_autohup_unrealize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_ahup_done_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_chk_ahup_time_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_up_toggled                 (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_down_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_total_up_toggled           (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_total_down_toggled         (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_ent_passwd_passwd_key_press_event   (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_bt_passwd_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_passwd_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_passwd_unrealize                (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_wnd_conserver_key_press_event       (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_mn_server_disconnect_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_line_offline_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_chk_ahup_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_chk_ahup_activated_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_ed_ahup_lines_changed               (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_chk_enable_mysql_toggled            (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_bt_asknum_cancel_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_asknum_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_wnd_askname_unrealize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_askname_realize                 (GtkWidget       *widget,
                                        gpointer         user_data);
